function basen(num, b)
	local t = {}
	while num > 0 do
		table.insert(t, 1, num % b)
		num = math.floor(num / b)
	end
	return table.concat(t)
end

function digitsBin(digits)
	local t = {}
	for i=1,#digits do
		local digit = digits.sub(digits, i, i)
		local bin = basen(tonumber(digit), 2)
		table.insert(t, bin ~= "" and bin or "0")
	end
	return t
end

function love.load()
	digits = {}
	show_seconds = true
end

function love.update(dt)
	format = "%H%M"
	if show_seconds then
		format = format .. "%S"
	end
	digits = digitsBin(os.date(format))
end

function love.draw()
	-- draw clock
	local size = 40
	love.graphics.translate(0, size*5)
	for i=1,#digits do
		local bin = string.reverse(digits[i])
		love.graphics.translate(size, 0)
		love.graphics.push()
		local limit = 4
		if i == 1 then
			limit = 2
		elseif i%2 == 1 then
			limit = 3
		end
		for j=1,limit do
			love.graphics.translate(0, -size)
			if string.sub(bin, j, j) == "1" then
				love.graphics.setColor(255, 255, 255)
			else
				love.graphics.setColor(64, 64, 64)
			end
			love.graphics.rectangle("fill", 0, 0, size*0.8, size*0.8)
		end
		love.graphics.pop()
	end
end

function love.keypressed(k)
	if k == "s" then
		show_seconds = not show_seconds
	elseif k == "escape" then
		love.event.quit()
	end
end

